@@ -1,6 +1,6 @@
 package App::duino::Command::upload;
 {
-  $App::duino::Command::upload::VERSION = '0.04';
+  $App::duino::Command::upload::VERSION = '0.05';
 }
 
 use strict;
@@ -18,7 +18,7 @@ App::duino::Command::upload - Upload a sketch to an Arduino
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -31,6 +31,7 @@ sub abstract { 'upload a sketch to an Arduino' }
 sub usage_desc { '%c upload %o [sketch.ino]' }
 
 sub opt_spec {
+	my $arduino_dir         = $ENV{'ARDUINO_DIR'}   || '/usr/share/arduino';
 	my $arduino_board       = $ENV{'ARDUINO_BOARD'} || 'uno';
 	my $arduino_port        = $ENV{'ARDUINO_PORT'}  || '/dev/ttyACM0';
 
@@ -44,6 +45,8 @@ sub opt_spec {
 	return (
 		[ 'board|b=s', 'specify the board model',
 			{ default => $arduino_board } ],
+		[ 'dir|d=s', 'specify the Arduino installation directory',
+			{ default => $arduino_dir } ],
 		[ 'port|p=s', 'specify the serial port to use',
 			{ default => $arduino_port } ],
 	);
